==> openshift-model-operator-5.7.3-sources.jar: io/fabric8/openshift/api/model/operator/v1/StaticIPAMDNSBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class StaticIPAMDNSBuilder extends io.fabric8.openshift.api.model.operator.v1.StaticIPAMDNSFluentImpl<io.fabric8.openshift.api.model.operator.v1.StaticIPAMDNSBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.StaticIPAMDNS,io.fabric8.openshift.api.model.operator.v1.StaticIPAMDNSBuilder>{
  public StaticIPAMDNSBuilder() {
    this(false);
  }
  public StaticIPAMDNSBuilder(java.lang.Boolean validationEnabled) {
    this(new StaticIPAMDNS(), validationEnabled);
  }
  public StaticIPAMDNSBuilder(io.fabric8.openshift.api.model.operator.v1.StaticIPAMDNSFluent<?> fluent) {
    this(fluent, false);
  }
  public StaticIPAMDNSBuilder(io.fabric8.openshift.api.model.operator.v1.StaticIPAMDNSFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new StaticIPAMDNS(), validationEnabled);
  }
  public StaticIPAMDNSBuilder(io.fabric8.openshift.api.model.operator.v1.StaticIPAMDNSFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.StaticIPAMDNS instance) {
    this(fluent, instance, false);
  }
  public StaticIPAMDNSBuilder(io.fabric8.openshift.api.model.operator.v1.StaticIPAMDNSFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.StaticIPAMDNS instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDomain(instance.getDomain()); 
    fluent.withNameservers(instance.getNameservers()); 
    fluent.withSearch(instance.getSearch()); 
    this.validationEnabled = validationEnabled; 
  }
  public StaticIPAMDNSBuilder(io.fabric8.openshift.api.model.operator.v1.StaticIPAMDNS instance) {
    this(instance,false);
  }
  public StaticIPAMDNSBuilder(io.fabric8.openshift.api.model.operator.v1.StaticIPAMDNS instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withDomain(instance.getDomain()); 
    this.withNameservers(instance.getNameservers()); 
    this.withSearch(instance.getSearch()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.StaticIPAMDNSFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.StaticIPAMDNS build() {
    StaticIPAMDNS buildable = new StaticIPAMDNS(fluent.getDomain(),fluent.getNameservers(),fluent.getSearch());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StaticIPAMDNSBuilder that = (StaticIPAMDNSBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operator-5.12.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/StaticIPAMDNSBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class StaticIPAMDNSBuilder extends io.fabric8.openshift.api.model.operator.v1.StaticIPAMDNSFluentImpl<io.fabric8.openshift.api.model.operator.v1.StaticIPAMDNSBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.StaticIPAMDNS,io.fabric8.openshift.api.model.operator.v1.StaticIPAMDNSBuilder>{
  public StaticIPAMDNSBuilder() {
    this(false);
  }
  public StaticIPAMDNSBuilder(java.lang.Boolean validationEnabled) {
    this(new StaticIPAMDNS(), validationEnabled);
  }
  public StaticIPAMDNSBuilder(io.fabric8.openshift.api.model.operator.v1.StaticIPAMDNSFluent<?> fluent) {
    this(fluent, false);
  }
  public StaticIPAMDNSBuilder(io.fabric8.openshift.api.model.operator.v1.StaticIPAMDNSFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new StaticIPAMDNS(), validationEnabled);
  }
  public StaticIPAMDNSBuilder(io.fabric8.openshift.api.model.operator.v1.StaticIPAMDNSFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.StaticIPAMDNS instance) {
    this(fluent, instance, false);
  }
  public StaticIPAMDNSBuilder(io.fabric8.openshift.api.model.operator.v1.StaticIPAMDNSFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.StaticIPAMDNS instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDomain(instance.getDomain()); 
    fluent.withNameservers(instance.getNameservers()); 
    fluent.withSearch(instance.getSearch()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public StaticIPAMDNSBuilder(io.fabric8.openshift.api.model.operator.v1.StaticIPAMDNS instance) {
    this(instance,false);
  }
  public StaticIPAMDNSBuilder(io.fabric8.openshift.api.model.operator.v1.StaticIPAMDNS instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withDomain(instance.getDomain()); 
    this.withNameservers(instance.getNameservers()); 
    this.withSearch(instance.getSearch()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.StaticIPAMDNSFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.StaticIPAMDNS build() {
    StaticIPAMDNS buildable = new StaticIPAMDNS(fluent.getDomain(),fluent.getNameservers(),fluent.getSearch());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StaticIPAMDNSBuilder that = (StaticIPAMDNSBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
